@@ -91,7 +91,8 @@ setMethod(
                   return(measure)
               }
 
-              minAlpha <- optimize(minD,c(-1e6,0))$minimum
+              minAlpha <- optimize(minD,c(-1e6,0),
+                                   tol=object@control.slopes$reltol)$minimum
 
 
               meanval <- log(shares) - log(idxShare) - minAlpha * (prices - idxPrice)
@@ -208,7 +209,7 @@ setMethod(
 
 
      ## Find price changes that set FOCs equal to 0
-     minResult <- BBsolve(object@priceStart,FOC,quiet=TRUE,...)
+     minResult <- BBsolve(object@priceStart,FOC,quiet=TRUE,control=object@control.equ,...)
 
       if(minResult$convergence != 0){warning("'calcPrices' nonlinear solver may not have successfully converged. 'BBsolve' reports: '",minResult$message,"'")}
 
@@ -265,7 +266,7 @@ setMethod(
 
 
       ## Find price changes that set FOCs equal to 0
-     minResult <- BBsolve(object@priceStart[prodIndex],FOC,quiet=TRUE,...)
+     minResult <- BBsolve(object@priceStart[prodIndex],FOC,quiet=TRUE,control=object@control.equ,...)
 
      if(minResult$convergence != 0){warning("'calcPricesHypoMon' nonlinear solver may not have successfully converged. 'BBSolve' reports: '",minResult$message,"'")}
 
@@ -291,6 +292,8 @@ logit.cap <- function(prices,shares,margins,
                       priceOutside=0,
                       priceStart = prices,
                       isMax=FALSE,
+                      control.slopes,
+                      control.equ,
                       labels=paste("Prod",1:length(prices),sep=""),
                       ...
                       ){
@@ -308,6 +311,13 @@ logit.cap <- function(prices,shares,margins,
                   priceStart=priceStart,shareInside=sum(shares),
                   labels=labels)
 
+    if(!missing(control.slopes)){
+      result@control.slopes <- control.slopes
+    }
+    if(!missing(control.equ)){
+      result@control.equ <- control.equ
+    }
+    
     ## Convert ownership vectors to ownership matrices
     result@ownerPre  <- ownerToMatrix(result,TRUE)
     result@ownerPost <- ownerToMatrix(result,FALSE)
